<?php

namespace Drupal\config2php\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Config Export to PHP array settings for this site.
 */
class Config2PhpSettingsForm extends ConfigFormBase {

  /**
   * The router builder.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routerBuilder;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);

    $instance->routerBuilder = $container->get('router.builder');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['config2php.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config2php_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config($this->getEditableConfigNames()[0]);

    $form['override'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Replace the default tab'),
      '#description' => $this->t('Navigate to a page for exporting a single
configuration to a PHP array instead of navigating to a page for exporting an
archive with full configuration in YAML format when clicking the "Export" menu
link.'),
      '#default_value' => $config->get('override'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config($this->getEditableConfigNames()[0]);

    $old_value = (bool) $config->get('override');
    $new_value = (bool) $form_state->getValue('override');

    if ($old_value !== $new_value) {
      $config->set('override', $new_value)->save();
      $this->routerBuilder->rebuild();
    }

    parent::submitForm($form, $form_state);
  }

}
